==> api_server_controller-0.1.7a4-py3-none-any.whl: asc/models/mercadopago.py <==
from sqlalchemy import ForeignKey
from sqlalchemy import Boolean
from sqlalchemy import VARCHAR
from sqlalchemy import Column
from sqlalchemy import Integer
from sqlalchemy import JSON
from sqlalchemy.orm import relationship

from asc.core.database.model import Model


class Payment(Model):
    __tablename__ = 'mercadopago_payment'
    __table_args__ = {'schema': 'private'}

    id_mercadopago_payment = Column(Integer, primary_key=True)
    id_mercadopago = Column(Integer, nullable=False)
    id_payment = Column(Integer, nullable=False)
    status = Column(VARCHAR)
    transaction_amount = Column(Integer)
    taxes_amount = Column(Integer)
    http_response = Column(JSON)
    http_postback = Column(JSON)

    relationship('PaymentMethod')


class PaymentMethod(Model):
    __tablename__ = 'mercadopago_payment_method'
    __table_args__ = {'schema': 'private'}

    id = Column(VARCHAR, primary_key=True)
    name = Column(VARCHAR, nullable=False)
    active = Column(Boolean,default=False,nullable=False)
    id_payment_type = Column(VARCHAR,nullable=False)


class User(Model):
    __tablename__ = 'mercadopago_user'
    __table_args__ = {'schema': 'private'}

    id = Column(Integer, primary_key=True)
    id_customer = Column(VARCHAR,nullable=False)
    id_client = Column(Integer,nullable=False)
    id_user = Column(Integer,nullable=False)


class Card(Model):
    __tablename__ = 'mercadopago_card'
    __table_args__ = {'schema': 'private'}

    id_user_card = Column(Integer, primary_key=True)
    secret = Column(VARCHAR,nullable=False)
    id_payment_method = Column(VARCHAR,nullable=False)

==> api_server_controller-0.2.3a7-py3-none-any.whl: asc/models/mercadopago.py <==
from sqlalchemy import ForeignKey
from sqlalchemy import Boolean
from sqlalchemy import VARCHAR
from sqlalchemy import Column
from sqlalchemy import Integer
from sqlalchemy import Numeric
from sqlalchemy import BigInteger
from sqlalchemy import JSON
from sqlalchemy.orm import relationship

from asc.core.database.model import Model


class Payment(Model):
    __tablename__ = 'mercadopago_payment'
    __table_args__ = {'schema': 'private'}

    id_mercadopago_payment = Column(Integer, primary_key=True)
    id_mercadopago = Column(BigInteger, nullable=False)
    id_payment = Column(Integer, nullable=False)
    status = Column(VARCHAR)
    transaction_amount = Column(Numeric(precision=7,scale=2))
    taxes_amount = Column(Integer)
    http_response = Column(JSON)
    http_postback = Column(JSON)

    relationship('PaymentMethod')


class PaymentMethod(Model):
    __tablename__ = 'mercadopago_payment_method'
    __table_args__ = {'schema': 'private'}

    id = Column(VARCHAR, primary_key=True)
    name = Column(VARCHAR, nullable=False)
    active = Column(Boolean,default=False,nullable=False)
    id_payment_type = Column(VARCHAR,nullable=False)


class User(Model):
    __tablename__ = 'mercadopago_user'
    __table_args__ = {'schema': 'private'}

    id = Column(Integer, primary_key=True)
    id_customer = Column(VARCHAR,nullable=False)
    id_client = Column(BigInteger,nullable=False)
    id_user = Column(Integer,nullable=False)


class Card(Model):
    __tablename__ = 'mercadopago_card'
    __table_args__ = {'schema': 'private'}

    id_user_card = Column(Integer, primary_key=True)
    secret = Column(VARCHAR,nullable=False)
    id_payment_method = Column(VARCHAR,nullable=False)
